fn apply(config: &mut InferenceConfig, field: &str, value: f64)Expand description
Write one validated value onto the config by gglib’s field name.
fn apply(config: &mut InferenceConfig, field: &str, value: f64)Write one validated value onto the config by gglib’s field name.